You are viewing a plain text version of this content. The canonical link for it is here.
Posted to common-dev@hadoop.apache.org by "Milind Bhandarkar (JIRA)" <ji...@apache.org> on 2006/08/01 23:11:15 UTC

[jira] Created: (HADOOP-410) Using HashMap instead of TreeMap for some maps in Namenode yields 17% performance improvement

Using HashMap instead of TreeMap for some maps in Namenode yields 17% performance improvement
---------------------------------------------------------------------------------------------

                 Key: HADOOP-410
                 URL: http://issues.apache.org/jira/browse/HADOOP-410
             Project: Hadoop
          Issue Type: Improvement
          Components: dfs
    Affects Versions: 0.5.0
         Environment: linux
            Reporter: Milind Bhandarkar
         Assigned To: Milind Bhandarkar
             Fix For: 0.5.0
         Attachments: hashmap.patch

For blocksMap in FSNameSystem and activeBlocks map in FSDirectory, if we use HashMap instead of TreeMap, it yields 17% performance improvement (without significant difference in memory consumption).
I am attaching a patch, alongwith a namenode benchmark.

-- 
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators: http://issues.apache.org/jira/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira

        

[jira] Resolved: (HADOOP-410) Using HashMap instead of TreeMap for some maps in Namenode yields 17% performance improvement

Posted by "Doug Cutting (JIRA)" <ji...@apache.org>.
     [ http://issues.apache.org/jira/browse/HADOOP-410?page=all ]

Doug Cutting resolved HADOOP-410.
---------------------------------

    Resolution: Fixed

I just committed this.  Thanks, Milind!

> Using HashMap instead of TreeMap for some maps in Namenode yields 17% performance improvement
> ---------------------------------------------------------------------------------------------
>
>                 Key: HADOOP-410
>                 URL: http://issues.apache.org/jira/browse/HADOOP-410
>             Project: Hadoop
>          Issue Type: Improvement
>          Components: dfs
>    Affects Versions: 0.5.0
>         Environment: linux
>            Reporter: Milind Bhandarkar
>         Assigned To: Milind Bhandarkar
>             Fix For: 0.5.0
>
>         Attachments: hashmap.patch
>
>
> For blocksMap in FSNameSystem and activeBlocks map in FSDirectory, if we use HashMap instead of TreeMap, it yields 17% performance improvement (without significant difference in memory consumption).
> I am attaching a patch, alongwith a namenode benchmark.

-- 
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators: http://issues.apache.org/jira/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira

        

[jira] Updated: (HADOOP-410) Using HashMap instead of TreeMap for some maps in Namenode yields 17% performance improvement

Posted by "Milind Bhandarkar (JIRA)" <ji...@apache.org>.
     [ http://issues.apache.org/jira/browse/HADOOP-410?page=all ]

Milind Bhandarkar updated HADOOP-410:
-------------------------------------

    Attachment: hashmap.patch

patch attached.

> Using HashMap instead of TreeMap for some maps in Namenode yields 17% performance improvement
> ---------------------------------------------------------------------------------------------
>
>                 Key: HADOOP-410
>                 URL: http://issues.apache.org/jira/browse/HADOOP-410
>             Project: Hadoop
>          Issue Type: Improvement
>          Components: dfs
>    Affects Versions: 0.5.0
>         Environment: linux
>            Reporter: Milind Bhandarkar
>         Assigned To: Milind Bhandarkar
>             Fix For: 0.5.0
>
>         Attachments: hashmap.patch
>
>
> For blocksMap in FSNameSystem and activeBlocks map in FSDirectory, if we use HashMap instead of TreeMap, it yields 17% performance improvement (without significant difference in memory consumption).
> I am attaching a patch, alongwith a namenode benchmark.

-- 
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators: http://issues.apache.org/jira/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira